@@ -170,6 +170,7 @@ gedit_view_class_init (GeditViewClass *klass)
 /* when the user right-clicks on a word, we move the cursor to the 
  * location of the clicked-upon word.
  */
+
 static gboolean
 button_press_event (GtkTextView *view, GdkEventButton *event, gpointer data) 
 {
@@ -252,13 +253,12 @@ gedit_view_init (GeditView  *view)
 	gedit_view_set_tab_size (view, gedit_prefs_manager_get_tabs_size ());
 	gedit_view_set_insert_spaces_instead_of_tabs (view, 
 			gedit_prefs_manager_get_insert_spaces ());
-	/*
+	
 	g_object_set (G_OBJECT (view->priv->text_view), 
-		      "cursor_visible", TRUE, 
-		      "show_margin", TRUE, 
-		      "margin", 80, 
+		      "show_margin", gedit_prefs_manager_get_display_right_margin (), 
+		      "margin", gedit_prefs_manager_get_right_margin_position (), 
 		      NULL);
-	*/
+	
 	g_object_set (G_OBJECT (view->priv->text_view),
 		      "smart-home-end", FALSE,
 		      NULL);
@@ -270,9 +270,10 @@ gedit_view_init (GeditView  *view)
 
 	g_signal_connect (G_OBJECT (view->priv->text_view), "populate-popup",
 			  G_CALLBACK (gedit_view_populate_popup), view);
-
+	
 	g_signal_connect (G_OBJECT (view->priv->text_view), "button-press-event",
 			  G_CALLBACK (button_press_event), NULL);
+
 }
 
 static void 
